is_monotone: Check is vector is monotone

Description Usage Arguments

Description

Determines if the sequence of vector elements are increasing or decreasing with the option to specify strictness.

Usage

1
is_monotone(x, strict)

Arguments

x

numeric vector

strict

logical; if true then strict monotonicity is determined


wzhorton/hortonlib documentation built on May 9, 2019, 8:19 a.m.